###############
Transformations
###############

This section contains the mathematical descriptions of (integral) transforms implemented in ODL.

.. toctree::
    :maxdepth: 3
    
    fourier_transform
